@@ -55,7 +55,10 @@ class SshClient():
                                          known_hosts=None,
                                          encryption_algs='+3des-cbc',
                                          kex_algs='+diffie-hellman-group1-sha1',
-                                         server_host_key_algs='+ssh-dss',
+                                         server_host_key_algs=[
+                                             'ssh-ed25519', 'rsa-sha2-256',
+                                             'rsa-sha2-512', 'ssh-rsa', 'ssh-dss'
+                                         ],
                                          tunnel=self._tun,
                                          username=self.username,
                                          password=self.password,
@@ -116,7 +119,8 @@ class SshClient():
         if self.verbose > 2:
             print('#!<{}'.format(r))
         if self.record is not None:
-            self.record.append([cmd, r])
+            rr = r[:-len(delimiter)] if delimiter else r
+            self.record.append([cmd, rr])
         return r
 
     async def scmd(self, cmd, timeout=5.0):
@@ -139,7 +143,7 @@ class SshClient():
             raise TypeError("br_name must be a string")
 
         # Get port_map
-        showstp = await self.scmd(f"brctl showstp {br_name} | grep '^\w* (\w)'")
+        showstp = await self.scmd(rf"brctl showstp {br_name} | grep '^\w* (\w)'")
         showstp = showstp.split('\n') if showstp else []
 
         if not showstp:
